==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/admin/inc/tree/license.php <==
<?php
      require 'inc/licence/ltranslatetables.php';
      
      function processLicences($showall)
      {
       global $api,$xml;
        $api = createobject("api"); 
       	$xml = $api->GetProperty("C_License");

       	$xmlparse = &new ParseXML();
        $xml = $xmlparse->GetXMLTreeFromString($xml);
        return getProducts($xml,$showall);
      }
      function getProducts($xml,$showall){
        global $api,$alang,$rsa,$T_T2;

        if ($xml["LICENSE"][0]["INFO"][0]["LICENSE"][0]["PRODUCTS"][0]["ITEM"])
        foreach ($xml["LICENSE"][0]["INFO"][0]["LICENSE"][0]["PRODUCTS"][0]["ITEM"] as  $product){
          $prod = $product["PRODUCT"][0]["VALUE"];

          $id = $T_T2[$prod];

          $item['product'] = $alang["TStrings_cl_".$id];
          $item['type'] = (string) $alang["TStrings_cfull"];
          $item['accounts'] = (string)$product["ACCOUNTS"][0]["VALUE"]==0?$alang["TStrings_cunlimited"]:$product["ACCOUNTS"][0]["VALUE"];
          $delphi_today = converttimetodelphi(mktime());
	       	$using_time = $delphi_today - $product['CREATIONDATE'][0]['VALUE'];
		      $item['expiresin'] = $alang["TStrings_clneverexpires"];
          $item['renewal'] = (string) ceil($product['EXPIRESAFTER'][0]['VALUE'] - $using_time);
          $item['exceed'] = "";
          $items[$id] = $item;
        }

        $ret = getAllProducts($items,$showall,$xml);
        return $ret;
      }

      function getAllProducts($items,$showall,$xml){
      
        global $api,$alang,$registered,$T_T;
        $pids = array("mailserver","webmail","ftp","spamengine","antivirus","instantmessaging","calendaring","syncml","sip");
         // Evaluation version
        if (!$items){
          $registered = false;
          foreach ($pids as $pid){
        	 $item['product'] = $alang["TStrings_cl_".$pid];
        	 $item['type'] = $alang["TStrings_clicenseeval"];
        	 $item['accounts'] = $alang["TStrings_cunlimited"];
        	 $delphi_today = converttimetodelphi(mktime(0,0,0));
	       	 $using_time = $delphi_today - $xml['LICENSE'][0]['TIMESTAMP'][0]['VALUE'];
		       $item['expiresin'] = (string) ceil(30 - $using_time)." ".$alang["TStrings_cldays"];
        	 $item['renewal'] = $item['expiresin'];
           $item['exceed'] = "";
           $items[$pid] = $item;
          }
          return $items;
        }else{
        //Merge registered and evaluation products
        $registered = true;
      /*  $sdis = array(0=>'MMPL','MMPLP','MMPP','MMPPP','MMPS','MMPSP','MMS');
        foreach ($sdis as $sid)
        	 if ($items[$sid]) $suite = $sid; // Find suite
        
        if (strlen($suite)==5) $sid = substr($suite,0,4);
        $pids[0] = $suite;*/
        
         foreach ($pids as $pid){
          if (!$items[$pid]){
           $item['product'] = $alang["TStrings_cl_".$pid];
        	 $item['type'] = $alang["TStrings_clicenseeval"];
        	 $item['accounts'] = $alang["TStrings_cunlimited"];
        	 $delphi_today = converttimetodelphi(mktime(0,0,0));
	       	 $using_time = $delphi_today - $xml['LICENSE'][0]['TIMESTAMP'][0]['VALUE'];
	       	 
		       $item['expiresin'] =$alang["TStrings_clicenseeval"];
        	 $item['renewal'] = $item['expiresin'];
           $item['exceed'] = "";
           if ($showall) $items[] = $item;
          }
        }
        return $items;
        }
      }
      
      function xmltotext($xml)
      {
        return $text;
      }
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/admin/inc/tree/license.php <==
<?php
      require 'inc/licence/ltranslatetables.php';
      
      function processLicences($showall)
      {
       global $api,$xml;
        $api = createobject("api"); 
       	$xml = $api->GetProperty("C_License_XMLFile");

       	$xmlparse = &new ParseXML();
        $xml = $xmlparse->GetXMLTreeFromString($xml);

        return getProducts($xml,$showall);
      }
      function getProducts($xml,$showall){
        global $api,$alang,$rsa,$T_T2;

        if ($xml["LICENSE"][0]["INFO"][0]["LICENSE"][0]["PRODUCTS"][0]["ITEM"])
        foreach ($xml["LICENSE"][0]["INFO"][0]["LICENSE"][0]["PRODUCTS"][0]["ITEM"] as  $product){
          $prod = $product["PRODUCT"][0]["VALUE"];

          $id = $T_T2[$prod];

          $item['product'] = $alang["TStrings_cl_".$id];
          $item['type'] = (string) $alang["TStrings_cfull"];
          $item['accounts'] = (string)$product["ACCOUNTS"][0]["VALUE"]==0?$alang["TStrings_cunlimited"]:$product["ACCOUNTS"][0]["VALUE"];
          $delphi_today = converttimetodelphi(mktime());
	       	$using_time = $delphi_today - $product['CREATIONDATE'][0]['VALUE'];
		      $item['expiresin'] = $alang["TStrings_clneverexpires"];
          $item['renewal'] = (string) ceil($product['EXPIRESAFTER'][0]['VALUE'] - $using_time);
          $item['exceed'] = "";
          $items[$id] = $item;
        }

        $ret = getAllProducts($items,$showall,$xml);
        return $ret;
      }

      function getAllProducts($items,$showall,$xml){
      
        global $api,$alang,$registered,$T_T;
        $pids = array("mailserver","webmail","ftp","spamengine","antivirus","instantmessaging","calendaring","syncml","sip","caldav","antispamlive","loganalyzer");
         // Evaluation version
        if (!$items){
          $registered = false;
          foreach ($pids as $pid){
        	 $item['product'] = $alang["TStrings_cl_".$pid];
        	 $item['type'] = $alang["TStrings_clicenseeval"];
        	 $item['accounts'] = $alang["TStrings_cunlimited"];
        	 $delphi_today = converttimetodelphi(mktime(0,0,0));
	       	 $using_time = $delphi_today - $xml['LICENSE'][0]['TIMESTAMP'][0]['VALUE'];
		       $item['expiresin'] = (string) ceil(30 - $using_time)." ".$alang["TStrings_cldays"];
        	 $item['renewal'] = $item['expiresin'];
           $item['exceed'] = "";
           $items[$pid] = $item;
          }
          return $items;
        }else{
        //Merge registered and evaluation products
        $registered = true;
      /*  $sdis = array(0=>'MMPL','MMPLP','MMPP','MMPPP','MMPS','MMPSP','MMS');
        foreach ($sdis as $sid)
        	 if ($items[$sid]) $suite = $sid; // Find suite
        
        if (strlen($suite)==5) $sid = substr($suite,0,4);
        $pids[0] = $suite;*/
         foreach ($pids as $pid){
          if (!$items[$pid]){
           $item['product'] = $alang["TStrings_cl_".$pid];
        	 $item['type'] = $alang["TStrings_clicenseeval"];
        	 $item['accounts'] = $alang["TStrings_cunlimited"];
        	 $delphi_today = converttimetodelphi(mktime(0,0,0));
	       	 $using_time = $delphi_today - $xml['LICENSE'][0]['TIMESTAMP'][0]['VALUE'];
	       	 
		       $item['expiresin'] =$alang["TStrings_clicenseeval"];
        	 $item['renewal'] = $item['expiresin'];
           $item['exceed'] = "";
           if ($showall) $items[] = $item;
          }
        }

        return $items;
        }
      }
      
      function xmltotext($xml)
      {
        return $text;
      }
?>
